@@ -566,10 +566,14 @@ struct dirent * osi_readdir( OSI_DIRECTORY *d )
 
         d->dd_loc += dp->d_reclen;
 
+        /* this causes a crash on irix, alignment?  not sure yet. */
+
+#ifndef SYSTEM_IRIX
         if( dp->d_ino == 0 )
         {
             continue;
         }
+#endif
 
         d->file = dp;
 
