@@ -139,6 +139,7 @@ OSI_SCAN_CONFIG * osi_config_new()
     global_block              = create_block();
 
     new_config->data          = string_list_new();
+    new_config->errors        = string_list_new();
     new_config->state	      = CONFIG_STATE_NULL;
 
     new_config->blocks        = list_new();
@@ -150,6 +151,7 @@ OSI_SCAN_CONFIG * osi_config_new()
     new_config->error_count   = 0;
 
     new_config->print_errors_on_verify = FALSE;
+    new_config->store_errors_on_verify = FALSE;
 
     /* we create a default global block here. */
 
@@ -178,6 +180,7 @@ void osi_config_destroy( OSI_SCAN_CONFIG *cfg )
     /* destroy config file data. */
 
     string_list_destroy( cfg->data );
+    string_list_destroy( cfg->errors );
 
     /* destroy the block names list. */
 
@@ -213,7 +216,10 @@ osi_bool osi_config_receive_first( OSI_SCAN_CONFIG *cfg, unsigned char *data,
         /* and set state to receiving.  then add incoming data.          */
 
         string_list_destroy( cfg->data );
+        string_list_destroy( cfg->errors );
+
         cfg->data = string_list_new();
+        cfg->errors = string_list_new();
 
         cfg->state = CONFIG_STATE_RECEIVING;
         return osi_config_receive( cfg, data, data_length );
@@ -760,21 +766,32 @@ osi_bool verify_param_values( string_list *modules, char *line )
 void print_config_error( OSI_SCAN_CONFIG *cfg, int line_number,
                          char *line, char *error, ... )
 {
-    va_list ap;
+    va_list args;
+    char buf[MAX_LINE_LENGTH] = "";
+    char msg[MAX_LINE_LENGTH] = "";
 
-    if ( cfg->print_errors_on_verify == FALSE )
+    if ( cfg->print_errors_on_verify == FALSE &&
+         cfg->store_errors_on_verify == FALSE )
     {
         return;
     }
 
-    fprintf( stderr, "\nline %d: ", line_number );
-    fprintf( stderr, "==> %s\n", line );
+    va_start( args, error );
+    osi_vsnprintf( msg, sizeof(msg), error, args );
+    va_end( args );
 
-    va_start( ap, error );
-    vfprintf( stderr, error, ap );
-    va_end( ap );
+    osi_snprintf( buf, sizeof(buf), "\nline %d: ==> %s\n%s\n",
+                  line_number, line, msg );
 
-    fprintf( stderr, "\n\n" );
+    if ( cfg->print_errors_on_verify )
+    {
+        fprintf( stderr, "%s\n", buf );
+    }
+
+    if ( cfg->store_errors_on_verify )
+    {
+        string_list_add_item( cfg->errors, buf );
+    }
 }
 
 
