@@ -132,6 +132,7 @@ typedef struct OSI_SCAN_CONFIG
 
     string_list *data;
     string_list *block_names;
+    string_list *errors;
 
     int state;
     unsigned char id[MAX_CONFIG_ID_LENGTH];
@@ -143,6 +144,7 @@ typedef struct OSI_SCAN_CONFIG
     osi_list blocks;
 
     osi_bool print_errors_on_verify;
+    osi_bool store_errors_on_verify;
 
 } OSI_SCAN_CONFIG;
 
