@@ -371,11 +371,31 @@ char * escape_filename( char *file_path, char *buffer, int buffer_size )
             *output++ = octals[(int)*input][2];
 
             input++;
-	}
+	    }
 
-	else
+        else if ( (*input) == ']' )
         {
-	    *output++ = *input++;
+            *output++ = '\\';
+            *output++ = '1';
+            *output++ = '3';
+            *output++ = '5';
+            
+            input++;
+        }
+
+        else if ( (*input) == '[' )
+        {
+            *output++ = '\\';
+            *output++ = '1';
+            *output++ = '3';
+            *output++ = '3';
+
+            input++;
+        }
+
+	    else
+        {
+	        *output++ = *input++;
         }
     }
 
