@@ -394,6 +394,14 @@ osi_bool osi_host_brief_write_file( const char *filepath,
 
                 case HOST_CONFIG_KEYWORD_SCHEDULE_START:
 
+                    /* never write zero, it prevents the scheduler */
+                    /* from working correctly.                     */
+
+                    if ( host_brief->schedule_start == 0 )
+                    {
+                        host_brief->schedule_start = (osi_get_time() - 61);
+                    }
+
                     osi_snprintf( buffer, sizeof(buffer), "%llu",
                                   host_brief->schedule_start );
 
