@@ -76,6 +76,7 @@ static struct m_keywords management_config_keywords[] =
     { "http_port", MANAGEMENT_CONFIG_KEYWORD_HTTP_PORT },
     { "http_host", MANAGEMENT_CONFIG_KEYWORD_HTTP_HOST },
     { "notify_email", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_EMAIL },
+    { "admin_email", MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL },
     { "notify_smtp_host", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST },
     { "notify_smtp_port", MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_PORT },
     { "hosts_directory", MANAGEMENT_CONFIG_KEYWORD_HOSTS_DIRECTORY },
@@ -380,6 +381,19 @@ osi_bool osi_management_config_write_file( const char *filepath,
    
                     break;
 
+               case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+    
+                    osi_strlcat( line, config->admin_email,
+                                 sizeof( line ) );
+    
+                    osi_strlcat( line, "\n", sizeof( line ) );
+
+                    fwrite( line, sizeof( char ), strlen( line ),
+                            config_file );
+    
+                    break;
+
+
                 case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST:
         
                     osi_strlcat( line, config->notify_smtp_host, 
@@ -538,6 +552,14 @@ osi_bool osi_management_config_sync( OSI_MANAGEMENT_CONFIG *config )
    
                 break;
 
+            case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+
+                osi_strlcat( line, config->admin_email, sizeof( line ) );
+                string_list_add_item( config->data, line );
+
+                break;
+
+
             case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST:
         
                 osi_strlcat( line, config->notify_smtp_host, sizeof( line ) );
@@ -665,6 +687,19 @@ osi_bool parse_management_config_line( char *line,
 
                 break;
 
+            case MANAGEMENT_CONFIG_KEYWORD_ADMIN_EMAIL:
+
+                get_management_config_line_value( line,
+                                                  value, sizeof( value ) );
+
+                if( strlen( value ) > 0 )
+                {
+                    osi_strlcpy( config->admin_email, value,
+                                 sizeof( config->admin_email ) );
+                }
+
+                break;
+
             case MANAGEMENT_CONFIG_KEYWORD_NOTIFY_SMTP_HOST:
 
                 get_management_config_line_value( line,
