@@ -125,6 +125,7 @@ void process_services_windows( SCANNER *scanner )
     {
         if( status != NULL )
         {
+            char *state = NULL;
             SCAN_RECORD_TEXT_1 record;
 
             initialize_scan_record( (SCAN_RECORD *)&record,
@@ -136,11 +137,45 @@ void process_services_windows( SCANNER *scanner )
             osi_snprintf( record.name, sizeof( record.name ),
                           "service:%s", status->lpServiceName );
 
+            switch ( status->ServiceStatus.dwCurrentState )
+            {
+                case SERVICE_CONTINUE_PENDING:
+                    state = "continue_pending";
+                    break;
+
+                case SERVICE_PAUSE_PENDING:
+                    state = "pause_pending";
+                    break;
+
+                case SERVICE_PAUSED:
+                    state = "paused";
+                    break;
+
+                case SERVICE_RUNNING:
+                    state = "running";
+                    break;
+
+                case SERVICE_START_PENDING:
+                    state = "start_pending";
+                    break;
+
+                case SERVICE_STOP_PENDING:
+                    state = "stop_pending";
+                    break;
+
+                case SERVICE_STOPPED:
+                    state = "stopped";
+                    break;
+
+                default:
+                    state = "unknown";
+            }
+
             osi_snprintf( record.data, sizeof( record.data ),
-                          "service:%s;dname:%s;status:%d",
+                          "service:%s;dname:%s;status:%s",
                           status->lpServiceName,
                           status->lpDisplayName,
-                          status->ServiceStatus.dwCurrentState );
+                          state );
 
             send_scan_data( scanner, (SCAN_RECORD *)&record );
             status++;
@@ -383,8 +418,13 @@ void process_kmods_linux( SCANNER *scanner )
     while( ( data = fgets( line, sizeof( line ), file ) ) != NULL )
     {
         char name[100] = "";
+        char size[20] = "";
+        char used[20] = "";
+        char address[100] = "";
 
-        get_token( line, name, sizeof(name) );
+        char *temp = NULL;
+
+        temp = get_token( line, name, sizeof(name) );
 
         if( strlen( name ) == 0 )
         {
@@ -397,11 +437,19 @@ void process_kmods_linux( SCANNER *scanner )
         osi_strlcpy( record.module_name, MODULE_NAME,
                      sizeof( record.module_name ) );
 
-        /* store name and data in record. */
+        /* store name in record. */
 
         osi_strlcpy( record.name, "kern:", sizeof( record.name ) );
         osi_strlcat( record.name, name, sizeof( record.name ) );        
-        osi_strlcpy( record.data, data, sizeof( record.data ) );
+
+        /* get and data, we don't need the "used by count".   */
+        /* the format is <name> <size> <usedby> - <address>...*/
+
+        temp = get_token( temp, size, sizeof(size) );
+        temp = get_token( temp, used, sizeof(used) );
+	
+        osi_snprintf( record.data, sizeof(record.data), "%s %s - %s",
+                      name, size, temp );
 
         send_scan_data( scanner, (SCAN_RECORD *)&record );
     }
@@ -419,7 +467,7 @@ static kmod_info_t * kmod_lookup(
     unsigned int kmod_count,
     int kmod_id)
 {
-    kmod_info_t * found_kmod = 0;  // returned
+    kmod_info_t * found_kmod = 0;  
     unsigned int i;
 
     for (i = 0; i < kmod_count; i++) {
@@ -438,8 +486,8 @@ static int kmod_ref_compare(const void * a, const void * b)
 {
     kmod_reference_t * r1 = (kmod_reference_t *)a;
     kmod_reference_t * r2 = (kmod_reference_t *)b;
-    // these are load indices, not CFBundleIdentifiers
-    // sorting high-low.
+    /*  these are load indices, not CFBundleIdentifiers */
+    /* sorting high-low. */
     return ((int)r2->info - (int)r1->info);
 }
 
@@ -447,7 +495,7 @@ static int kmod_compare(const void * a, const void * b)
 {
     kmod_info_t * k1 = (kmod_info_t *)a;
     kmod_info_t * k2 = (kmod_info_t *)b;
-    // these are load indices, not CFBundleIdentifiers
+    /*  these are load indices, not CFBundleIdentifiers */
     return (k1->id - k2->id);
 }
 
@@ -456,7 +504,7 @@ void process_kmods_darwin( SCANNER *scanner )
     port_t host_port = PORT_NULL;
     kmod_info_t * kmod_list;
     kmod_info_t * this_kmod;
-    int kmod_bytecount;  // not really used
+    int kmod_bytecount;  
     int kmod_count;
     kern_return_t mach_result = KERN_SUCCESS;
     kmod_reference_t * kmod_ref;
