@@ -327,7 +327,7 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
                     SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r1;
 
                     log_cmp_message( LOG_ID_CMP_GENERIC_DIFF, context,
-                                     "[%s][cmp][%s][%s][%s,%s]",
+                                     "[%s][cmp][%s][%s][%s][%s]",
                                      context->host, rec->module_name,
                                      rec->name, r1_data, r2_data );
 
@@ -789,22 +789,22 @@ void compare_db_with_default_for_host( OSI_DB *db, OSI_HOST *host )
 
                 if( strlen( host->notify_email ) > 0 )
                 {
-                    md_notify_admin( host->notify_email, context, show_url );
+                    md_notify( host->notify_email, context, show_url );
                 }
 
                 else
                 {
-                    md_notify_admin( config->notify_email, context, show_url );
+                    md_notify( config->notify_email, context, show_url );
                 }
             }
         }
 
         /* ALWAYS send notification to admin email. */
 
-        else if ( strlen( config->admin_email ) )
+        if ( strlen( config->admin_email ) > 0 )
         {
             osi_bool show_url = !( host->db_flags & OSI_DB_AUTOACCEPT );
-            md_notify_admin( config->admin_email, context, show_url );
+            md_notify( config->admin_email, context, show_url );
         }
 
         osi_db_ctx_destroy( context );
@@ -867,7 +867,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
         if( print_mask & ATTR_CHECKSUM )
         {
             log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
-                           "[%s][cmp][%s][checksum][%s,%s]",
+                           "[%s][cmp][%s][checksum][%s][%s]",
                            context->host, r1->path, r1->checksum,r2->checksum );
 
             context->diff_count++;
@@ -885,12 +885,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->device );
 
             log_cmp_message( LOG_ID_CMP_DEVICE, context,
-                             "[%s][cmp][%s][device][%s,%s]",
+                             "[%s][cmp][%s][device][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_DEVICE, context,
-                             "[%s][cmp][%s][device][%llu,%llu]",
+                             "[%s][cmp][%s][device][%llu][%llu]",
                              context->host, r1->path, r1->device, r2->device );
             #endif
 
@@ -908,14 +908,14 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->inode );
 
             log_cmp_message( LOG_ID_CMP_INODE, context,
-                             "[%s][cmp][%s][inode][%s,%s]",
+                             "[%s][cmp][%s][inode][%s][%s]",
                              context->host, r1->path, left, right );
 
             #else
 
             
             log_cmp_message( LOG_ID_CMP_INODE, context,
-                             "[%s][cmp][%s][inode][%llu,%llu]",
+                             "[%s][cmp][%s][inode][%llu][%llu]",
                               context->host,r1->path, r1->inode, r2->inode );
             #endif
 
@@ -925,7 +925,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
         if( print_mask & ATTR_PERMISSIONS )
         {
             log_cmp_message( LOG_ID_CMP_PERM, context,
-                             "[%s][cmp][%s][perm][%s,%s]", context->host,
+                             "[%s][cmp][%s][perm][%s][%s]", context->host,
                              r1->path, r1->permissions_string, 
                              r2->permissions_string );
 
@@ -944,12 +944,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->links );
 
             log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
-                             "[%s][cmp][%s][links][%s,%s]",
+                             "[%s][cmp][%s][links][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_SYMLINKS, context,
-                             "[%s][cmp][%s][links][%llu,%llu]",
+                             "[%s][cmp][%s][links][%llu][%llu]",
                              context->host,
                              r1->path, r1->links, r2->links );
             #endif
@@ -968,12 +968,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->uid );
 
             log_cmp_message( LOG_ID_CMP_UID, context,
-                             "[%s][cmp][%s][uid][%s,%s]",
+                             "[%s][cmp][%s][uid][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_UID, context,
-                             "[%s][cmp][%s][uid][%llu,%llu]",
+                             "[%s][cmp][%s][uid][%llu][%llu]",
                              context->host, r1->path, r1->uid, r2->uid );
             #endif
 
@@ -991,12 +991,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->gid );
 
             log_cmp_message( LOG_ID_CMP_GID, context,
-                             "[%s][cmp][%s][gid][%s,%s]",
+                             "[%s][cmp][%s][gid][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_GID, context,
-                             "[%s][cmp][%s][gid][%llu,%llu]",
+                             "[%s][cmp][%s][gid][%llu][%llu]",
                              context->host, r1->path, r1->gid, r2->gid );
             #endif
 
@@ -1015,7 +1015,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_mtime ) );
 
             log_cmp_message( LOG_ID_CMP_MTIME, context,
-                             "[%s][cmp][%s][mtime][%s,%s]",
+                             "[%s][cmp][%s][mtime][%s][%s]",
                              context->host, r1->path, left_mtime, right_mtime );
 
             context->diff_count++;
@@ -1033,7 +1033,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_atime ) );
 
             log_cmp_message( LOG_ID_CMP_ATIME, context,
-                             "[%s][cmp][%s][atime][%s,%s]",
+                             "[%s][cmp][%s][atime][%s][%s]",
                              context->host, r1->path, left_atime, right_atime );
 
             context->diff_count++;
@@ -1051,7 +1051,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_ctime ) );
 
             log_cmp_message( LOG_ID_CMP_CTIME, context,
-                             "[%s][cmp][%s][ctime][%s,%s]",
+                             "[%s][cmp][%s][ctime][%s][%s]",
                              context->host, r1->path, left_ctime, right_ctime );
 
             context->diff_count++;
@@ -1068,12 +1068,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->device_type );
 
             log_cmp_message( LOG_ID_CMP_DEVICETYPE, context,
-                             "[%s][cmp][%s][devicetype][%s,%s]",
+                             "[%s][cmp][%s][devicetype][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
            log_cmp_message( LOG_ID_CMP_DEVICETYPE, context, 
-                           "[%s][cmp][%s][devicetype][%llu,%llu]",
+                           "[%s][cmp][%s][devicetype][%llu][%llu]",
                             context->host, r1->path,
                             r1->device_type, r2->device_type );
             #endif
@@ -1092,12 +1092,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->bytes );
 
             log_cmp_message( LOG_ID_CMP_BYTES, context,
-                             "[%s][cmp][%s][bytes][%s,%s]",
+                             "[%s][cmp][%s][bytes][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_BYTES, context,
-                             "[%s][cmp][%s][bytes][%llu,%llu]",
+                             "[%s][cmp][%s][bytes][%llu][%llu]",
                              context->host, r1->path, r1->bytes, r2->bytes );
             #endif
 
@@ -1115,12 +1115,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->blocks );
 
             log_cmp_message( LOG_ID_CMP_BLOCKS, context,
-                             "[%s][cmp][%s][blocks][%s,%s]",
+                             "[%s][cmp][%s][blocks][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_BLOCKS, context,
-                             "[%s][cmp][%s][blocks][%llu,%llu]",
+                             "[%s][cmp][%s][blocks][%llu][%llu]",
                              context->host, r1->path, r1->blocks, r2->blocks );
             #endif
 
@@ -1138,12 +1138,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->block_size );
 
             log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
-                             "[%s][cmp][%s][blocksize][%s,%s]",
+                             "[%s][cmp][%s][blocksize][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_BLOCKSIZE, context,
-                             "[%s][cmp][%s][blocksize][%llu,%llu]",
+                             "[%s][cmp][%s][blocksize][%llu][%llu]",
                              context->host, r1->path,
                              r1->block_size, r2->block_size );
             #endif
@@ -1193,7 +1193,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
         if( print_mask & ATTR_CHECKSUM ) 
         {
             log_cmp_message( LOG_ID_CMP_CHECKSUM, context,
-                             "[%s][cmp][%s][checksum][%s,%s]",
+                             "[%s][cmp][%s][checksum][%s][%s]",
                              context->host, r1->path,
                              r1->checksum, r2->checksum );
 
@@ -1212,12 +1212,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->device );
 
             log_cmp_message( LOG_ID_CMP_DEVICE, context,
-                             "[%s][cmp][%s][device][%s,%s]",
+                             "[%s][cmp][%s][device][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_DEVICE, context,
-                             "[%s][cmp][%s][device][%llu,%llu]",
+                             "[%s][cmp][%s][device][%llu][%llu]",
                              context->host, r1->path, 
                              r1->device, r2->device );
             #endif
@@ -1236,12 +1236,12 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
             osi_snprintf( right, sizeof(right), "%llu", r2->bytes );
 
             log_cmp_message( LOG_ID_CMP_BYTES, context,
-                             "[%s][cmp][%s][bytes][%s,%s]",
+                             "[%s][cmp][%s][bytes][%s][%s]",
                              context->host, r1->path, left, right );
             #else
 
             log_cmp_message( LOG_ID_CMP_BYTES, context,
-                             "[%s][cmp][%s][bytes][%llu,%llu]",
+                             "[%s][cmp][%s][bytes][%llu][%llu]",
                              context->host, r1->path,
                              r1->bytes, r2->bytes );
             #endif
@@ -1262,7 +1262,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
 
 
             log_cmp_message( LOG_ID_CMP_MTIME, context,
-                             "[%s][cmp][%s][mtime][%s,%s]",
+                             "[%s][cmp][%s][mtime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
             context->diff_count++;
@@ -1280,7 +1280,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_time ) );
 
             log_cmp_message( LOG_ID_CMP_ATIME, context,
-                             "[%s][cmp][%s][atime][%s,%s]",
+                             "[%s][cmp][%s][atime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
             context->diff_count++;
@@ -1298,7 +1298,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
                          sizeof( right_time ) );
 
             log_cmp_message( LOG_ID_CMP_CTIME, context,
-                             "[%s][cmp][%s][ctime][%s,%s]",
+                             "[%s][cmp][%s][ctime][%s][%s]",
                              context->host, r1->path, left_time, right_time );
 
             context->diff_count++;
@@ -1307,7 +1307,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
         if( print_mask & ATTR_OWNER_SID )
         {
             log_cmp_message( LOG_ID_CMP_OWNER_SID, context,
-                      "[%s][cmp][%s][owner_sid][%s:%s,%s:%s]",
+                      "[%s][cmp][%s][owner_sid][%s:%s][%s:%s]",
                       context->host, r1->path,
                       r1->owner, r1->owner_sid,
                       r2->owner, r2->owner_sid );
@@ -1318,7 +1318,7 @@ void record_file_differences( OSI_DB_CTX *context, SCAN_RECORD *record1,
         if( print_mask & ATTR_GROUP_SID )
         {
             log_cmp_message( LOG_ID_CMP_GROUP_SID, context,
-                      "[%s][cmp][%s][group_sid][%s:%s,%s:%s]",
+                      "[%s][cmp][%s][group_sid][%s:%s][%s:%s]",
                       context->host, r1->path,
                       r1->group, r1->group_sid,
                       r2->group, r2->group_sid );
