@@ -100,7 +100,7 @@ void osi_set_host_defaults( OSI_HOST *host )
         host->notify_enabled = 0;
         host->notify_flags = 0;
 
-        host->schedule_start = 0;
+        host->schedule_start = (osi_get_time() - 61);
         host->schedule_period = 0;
 
         host->port = DEFAULT_SCAN_AGENT_PORT;
