@@ -27,11 +27,11 @@
 #ifndef MD_NOTIFY_H_
 #define MD_NOTIFY_H_
 
-void md_notify_admin( const char *email, OSI_DB_CTX *context,osi_bool show_url);
+void md_notify( const char *email, OSI_DB_CTX *context,osi_bool show_url);
 
-void md_notify_admin_session_rekey( const char *host, const char *email );
+void md_notify_session_rekey( const char *host, const char *email );
 
-void md_notify_admin_scan_failed( const char *host,
+void md_notify_scan_failed( const char *host,
                                    const char *email,
                                    unsigned long scheduled_time,
                                    const char *message );
