@@ -240,10 +240,20 @@ exit_gracefully:
                         (host_brief->notify_flags & OSI_NOTIFY_SCAN_FAILED) ) )
                     {
 
-                        md_notify_admin_scan_failed( s->host,
-                                                     email,
-                                                     current_seconds,
-                                                     failure_message );
+                        md_notify_scan_failed( s->host,
+                                               email,
+                                               current_seconds,
+                                               failure_message );
+                    }
+
+                    /* always notify admin email. */
+
+                    if ( strlen( config->admin_email ) > 0 )
+                    {
+                        md_notify_scan_failed( s->host,
+                                               config->admin_email,
+                                               current_seconds,
+                                               failure_message );
                     }
 
                     if( host_brief )
