@@ -435,7 +435,14 @@ osi_bool perform_session_key_negotiation( SSL *ssl, OSI_HOST *host )
             if( ( host->notify_enabled ) &&
                 ( host->notify_flags & OSI_NOTIFY_AGENT_REKEY ) )
             {
-                md_notify_admin_session_rekey( host->name, email );
+                md_notify_session_rekey( host->name, email );
+            }
+
+            /* always notify the admin. */
+
+            if ( strlen( config->admin_email ) > 0 )
+            {
+                md_notify_session_rekey( host->name,config->admin_email );
             }
 
             log_warning( LOG_ID_SESSION_KEY_LOST, host->host,
