@@ -1030,7 +1030,7 @@ void initialize_ssl()
         halt( EXIT_CODE_ERROR );
     }
 
-    SSL_CTX_set_verify( ssl_context, SSL_VERIFY_PEER, ssl_verify_callback );
+    SSL_CTX_set_verify( ssl_context, 0, ssl_verify_callback );
     SSL_CTX_set_verify_depth( ssl_context, OSIRISMD_SERVER_CERT_CHAIN_DEPTH );
     SSL_CTX_set_options( ssl_context, OSIRISMD_SSL_OPTIONS );
 
